/************************************************************************************
**    SIMphoto is an aplication based on single image photogrammetry. It is useful
**    for creating and printing a photomap. The software is designed for close
**    range photogrammtery. Outputs are usable in the field of heritage preservation.
**    Copyright (C) 2009 David Cizek
**
**    This program is free software: you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation, either version 3 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**    How to contact me: cizekdav@gmail.com
**
***********************************************************************************/

#include "memoryclass.h"

MemoryClass::MemoryClass()
{
    previousImage = 0;
    networkDistances.setZero();
    objectCoordinates.setZero();
    diagonal = 0;
    numberOfChanges = 0;
    previousPixelSize = 0.0;
}

void MemoryClass::setNetworkDistances(Matrix<double, 6, 1> dist)
{
    networkDistances = dist;
}

void MemoryClass::setNetworkCoordinates(Matrix<double, 4, 2> coords)
{
    networkCoordinates = coords;
}

void MemoryClass::setActionName(QString name)
{
    actionName = name;
}

void MemoryClass::setDiagonal(int diag)
{
    diagonal = diag;
}

void MemoryClass::setPixelSize(double size)
{
    pixelSize = size;
}

void MemoryClass::setObjectCoordinates(Matrix<double, 9, 2> coords)
{
    objectCoordinates = coords;
}

void MemoryClass::setPreviousImage(QImage *image)
{
    if(previousImage)
        previousImage->~QImage();

    previousImage = new QImage(*image);
}

void MemoryClass::addNumberOfChanges()
{
    numberOfChanges++;
}

void MemoryClass::reduceNumberOfChanges()
{
    numberOfChanges--;
}

void MemoryClass::setNumberOfChanges(int number)
{
    numberOfChanges = number;
}

void MemoryClass::setPreviousPixelSize(double size)
{
    previousPixelSize = size;
}

void MemoryClass::setObjCoordsZero()
{
    objectCoordinates.setZero();
}

void MemoryClass::setObjectCoordsKey(Matrix<double, 2, 1> key)
{
    objectCoordsKey = key;
}

void MemoryClass::setCornersCrd(bool crd)
{
    cornersCrd = crd;
}

void MemoryClass::setPreviousCornersCrd(bool crd)
{
    previousCornersCrd = crd;
}

void MemoryClass::setPreviousObjectCoordsKey(Matrix<double, 2, 1> key)
{
    previousObjectCoordsKey = key;
}

//return all distances in network
Matrix<double, 6, 1> MemoryClass::getNetworkDistances()
{
    return networkDistances;
}

//return all coordinate of points in network
Matrix<double, 4, 2> MemoryClass::getNetworkCoordinates()
{
    return networkCoordinates;
}

//return name of the actual action
QString MemoryClass::getActionName()
{
    return actionName;
}

//return previous image (called by undo act)
QImage* MemoryClass::getPreviousImage()
{
    return previousImage;
}

//return which dialonal was measured
int MemoryClass::getDiagonal()
{
    return diagonal;
}

//return how many times the image was modified
int MemoryClass::getNumberOfChanges()
{
    return numberOfChanges;
}

//return size of pixel
double MemoryClass::getPixelSize()
{
    return pixelSize;
}

//return object coordinates of control points
Matrix<double, 9, 2> MemoryClass::getObjectCoordinates()
{
    return objectCoordinates;
}

//return coefficients that are used for showing aktual object coordinates
Matrix<double, 2, 1> MemoryClass::getObjectCoordsKey()
{
    return MemoryClass::objectCoordsKey;
}

//return previous coefficients
Matrix<double, 2, 1> MemoryClass::getPreviousObjectCoordsKey()
{
    return previousObjectCoordsKey;
}

//return previous pixel size
double MemoryClass::getPreviousPixelSize()
{
    return previousPixelSize;
}

//return object coordinates of raster corners
bool MemoryClass::getCornersCrd()
{
    return cornersCrd;
}

//return previous object coordinates of raster corners
bool MemoryClass::getPreviousCornersCrd()
{
    return previousCornersCrd;
}
